@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,16 +21,14 @@
 using namespace KAddressBookGrantlee;
 
 ContactGrantleeEmail::ContactGrantleeEmail(const KContacts::Addressee &addressee, const KContacts::Email &email, QObject *parent)
-    : QObject(parent),
-      mEmail(email),
-      mAddressee(addressee)
+    : QObject(parent)
+    , mEmail(email)
+    , mAddressee(addressee)
 {
-
 }
 
 ContactGrantleeEmail::~ContactGrantleeEmail()
 {
-
 }
 
 QString ContactGrantleeEmail::email() const
@@ -43,7 +41,7 @@ bool ContactGrantleeEmail::preferred() const
 {
     const QStringList value = mEmail.parameters().value(QStringLiteral("type"));
     //Validate PREF and pref
-    return value.contains(QStringLiteral("pref"), Qt::CaseInsensitive);
+    return value.contains(QLatin1String("pref"), Qt::CaseInsensitive);
 }
 
 QString ContactGrantleeEmail::emailFormatted() const
